
# Salus iT600
This module connects to your Salus gateway

Supported devices:
- VS20WRF

## Usage
```
define Salus_iT600 fhempy pyit600 host euid

e.g. define Salus_iT600 fhempy pyit600 192.168.178.96 002F4A181385EEAE
```

## Attributes
